@@ -395,25 +395,15 @@ pub fn get_args(version: &str) -> ArgMatches {
                 ),
         )
         .subcommand(
-            App::new("summary")
-                .about("Gets alignment summary stats")
-                .arg(
-                    Arg::with_name("input")
-                        .short("i")
-                        .long("input")
-                        .help("Gets summary from a file")
-                        .takes_value(true)
-                        .required_unless("dir")
-                        .conflicts_with_all(&["dir", "wildcard"])
-                        .value_name("PATH"),
-                )
+            App::new("extract")
+                .about("Extract sequences from a collection of alignments")
                 .arg(
                     Arg::with_name("dir")
                         .short("d")
                         .long("dir")
-                        .help("Gets summary from alignment files")
+                        .help("Inputs a directory path to alignments")
                         .takes_value(true)
-                        .conflicts_with_all(&["input", "wildcard"])
+                        .conflicts_with("wildcard")
                         .value_name("PATH"),
                 )
                 .arg(
@@ -443,16 +433,60 @@ pub fn get_args(version: &str) -> ArgMatches {
                             "phylip",
                         ]),
                 )
+                .arg(
+                    Arg::with_name("regex")
+                        .long("re")
+                        .help("Extract sequence IDs that match regular expression")
+                        .conflicts_with_all(&["id", "file"])
+                        .takes_value(true)
+                        .require_equals(true)
+                        .value_name("REGEX")       
+                )
+                .arg(
+                    Arg::with_name("file")
+                        .long("file")
+                        .help("Extract sequence IDs that match regular expression")
+                        .conflicts_with_all(&["id", "regex"])
+                        .takes_value(true)
+                        .value_name("A-TEXT-FILE-PATH")       
+                )
+                .arg(
+                    Arg::with_name("id")
+                        .long("id")
+                        .help("Extract sequence in a list of IDs")
+                        .conflicts_with_all(&["regex", "file"])
+                        .required_unless_all(&["regex", "file"])
+                        .takes_value(true)
+                        .multiple(true)
+                        .value_name("STRING")       
+                )
                 .arg(
                     Arg::with_name("output")
                         .short("o")
                         .long("output")
-                        .help("Uses a costume output filename")
+                        .help("Specifies a directory name")
                         .takes_value(true)
                         .required(true)
-                        .default_value("SEGUL-stats")
+                        .default_value("SEGUL-extract")
                         .value_name("STRING"),
                 )
+                .arg(
+                    Arg::with_name("output-format")
+                        .short("F")
+                        .long("output-format")
+                        .help("Sets target output format")
+                        .takes_value(true)
+                        .default_value("nexus")
+                        .value_name("SEQ-FORMAT")
+                        .possible_values(&[
+                            "nexus",
+                            "phylip",
+                            "fasta",
+                            "fasta-int",
+                            "nexus-int",
+                            "phylip-int",
+                        ]),
+                )
                 .arg(
                     Arg::with_name("datatype")
                         .long("datatype")
@@ -463,15 +497,6 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .default_value("dna")
                         .possible_values(&["dna", "aa", "ignore"]),
                 )
-                .arg(
-                    Arg::with_name("percent-interval")
-                        .long("interval")
-                        .help("Sets a custom percentage interval value for counting data matrix completeness")
-                        .takes_value(true)
-                        .value_name("INTEGER")
-                        .default_value("5")
-                        .possible_values(&["1", "2", "5", "10"]),
-                ),
         )
         .get_matches()
 }
